@@ -1,4 +1,7 @@
 import inspect
+import sys, os
+
+sys.path.insert (0,os.path.dirname(__file__))
 
 import HMC5883L
 import MPU6050
